==> Mudlib-CD.00.28.tar.gz: lib/std/remote_npc.c <==
/*
   /std/remote_npc.c

   A small gadget for listning in and controling NPC's

*/
#pragma save_binary

inherit "/std/object";

static 	object	link_player,
		link_monster;
static	int	link_toggle;

#define SEQ_LINK "_remnpc_link"

create_object()
{
    set_name("wand");
    add_name("remote");
    add_name("controller"); 
    set_short("silver wand");
    set_long("@@long_func");
}
    
long_func()
{
    string str;

    str = "It is quite definetely a wand of control.\n";
    if (link_monster)
    {
        if (link_monster && environment(this_object()) == this_player())
	    str += "You feel the presence of " + 
		link_monster->query_name() + " the " +
		link_monster->query_race_name() +
		".\n";
	else
	    str += "It seems to be active.\n";
    }
    return str;
}
	

set_npc(monster)
{
    if (!link_monster)
    {
	link_monster = monster;
	link_toggle = 1;
    }
}


link_intext(str)
{
    string name;

    if (!link_toggle)
	return;
    if (link_player)
    {
	name = "#" + link_monster->query_name() + "# ";
	str = implode(explode(str, "\n"), "\n" + name);
	tell_object(link_player, name + str + "\n");
    }
}

init()
{
    if (environment(this_object()) == this_player() &&
	this_player()->query_wiz_level())
    {
	add_action("remote_cmd", "#", 1);
	add_action("posstoggle", "controltoggle");
    }
}

remote_cmd(str)
{
    string cmd, name, exe, *many;

    if (!link_monster)
    {
	destruct(this_object());
	return 0;
    }
    cmd = query_verb() + (str ? (" " + str) : "");

    if (sscanf(cmd, "#%s#%s", name, exe) == 2)
    {
	if (name != lower_case(link_monster->query_name()))
	    return 0;
    }
    else
	exe = extract(cmd, 1);

    if (sscanf(exe, "!%s", cmd) == 1)
    {
	many = explode(cmd + "%%", "%%");
	if (!sizeof(link_monster->seq_query(SEQ_LINK)))
	    link_monster->seq_new(SEQ_LINK);
	link_monster->seq_clear(SEQ_LINK);
	link_monster->seq_addfirst(SEQ_LINK,many);
	write("Ordered sequence actions.\n");
	return 1;
    }
    else if (sscanf(exe, "?%s", cmd) == 1)
    {
	write("Give control commands with syntax: " +
		"#<name#>command or #<name#>!cmd%%cmd\n");
	write("! indicates a delayed command sequence\n");
	write("<name#> is an optional name specified if needed.\n");
	return 1;
    }
    else
    {
	notify_fail("#" + link_monster->query_name() + "# What?");
	return link_monster->command(exe);
    }
}

posstoggle(str)
{
    notify_fail("Toggle control of what monster? <Give name of monster>\n");
    if (!link_monster || !link_monster->id(str))
	return 0;
    if (link_toggle) 
    {
	link_toggle = 0;
	write("Toggled control of " +
	      link_monster->query_name() + " off.\n");
    }
    else
    {
	link_toggle = 1;
	write("Toggled control of " +
	      link_monster->query_name() + " on.\n");
    }
    return 1;
}

enter_env(dest, old)
{
    ::enter_env(dest, old);
    if (living(dest))
	link_player = environment(this_object());
}

leave_env(old, dest)
{
    ::leave_env(old,dest);
    link_player = 0;
}

==> Mudlib-CD.00.30.tar.gz: lib/std/remote_npc.c <==
/*
   /std/remote_npc.c

   A small gadget for listning in and controling NPC's

*/
#pragma save_binary

inherit "/std/object";

static 	object	link_player,
		link_monster;
static	int	link_toggle;

#define SEQ_LINK "_remnpc_link"

create_object()
{
    set_name("wand");
    add_name("remote");
    add_name("controller"); 
    set_short("silver wand");
    set_long("@@long_func");
}
    
long_func()
{
    string str;

    str = "It is quite definetely a wand of control.\n";
    if (link_monster)
    {
        if (link_monster && environment(this_object()) == this_player())
	    str += "You feel the presence of " + 
		link_monster->query_name() + " the " +
		link_monster->query_race_name() +
		".\n";
	else
	    str += "It seems to be active.\n";
    }
    return str;
}
	

set_npc(monster)
{
    if (!link_monster)
    {
	link_monster = monster;
	link_toggle = 1;
    }
}


link_intext(str)
{
    string name;

    if (!link_toggle)
	return;
    if (link_player)
    {
	name = "#" + link_monster->query_name() + "# ";
	str = implode(explode(str, "\n"), "\n" + name);
	tell_object(link_player, name + str + "\n");
    }
}

init()
{
    if (environment(this_object()) == this_player() &&
	this_player()->query_wiz_level())
    {
	add_action("remote_cmd", "#", 1);
	add_action("posstoggle", "controltoggle");
    }
}

remote_cmd(str)
{
    string cmd, name, exe, *many;

    if (!link_monster)
    {
	destruct();
	return 0;
    }
    cmd = query_verb() + (str ? (" " + str) : "");

    if (sscanf(cmd, "#%s#%s", name, exe) == 2)
    {
	if (name != lower_case(link_monster->query_name()))
	    return 0;
    }
    else
	exe = extract(cmd, 1);

    if (sscanf(exe, "!%s", cmd) == 1)
    {
	many = explode(cmd + "%%", "%%");
	if (!sizeof(link_monster->seq_query(SEQ_LINK)))
	    link_monster->seq_new(SEQ_LINK);
	link_monster->seq_clear(SEQ_LINK);
	link_monster->seq_addfirst(SEQ_LINK,many);
	write("Ordered sequence actions.\n");
	return 1;
    }
    else if (sscanf(exe, "?%s", cmd) == 1)
    {
	write("Give control commands with syntax: " +
		"#<name#>command or #<name#>!cmd%%cmd\n");
	write("! indicates a delayed command sequence\n");
	write("<name#> is an optional name specified if needed.\n");
	return 1;
    }
    else
    {
	notify_fail("#" + link_monster->query_name() + "# What?\n");
	return link_monster->command(exe);
    }
}

posstoggle(str)
{
    notify_fail("Toggle control of what monster? <Give name of monster>\n");
    if (!link_monster || !link_monster->id(str))
	return 0;
    if (link_toggle) 
    {
	link_toggle = 0;
	write("Toggled control of " +
	      link_monster->query_name() + " off.\n");
    }
    else
    {
	link_toggle = 1;
	write("Toggled control of " +
	      link_monster->query_name() + " on.\n");
    }
    return 1;
}

enter_env(dest, old)
{
    ::enter_env(dest, old);
    if (living(dest))
	link_player = environment(this_object());
}

leave_env(old, dest)
{
    ::leave_env(old,dest);
    link_player = 0;
}
